@@ -14,7 +14,6 @@ from typing import (
     NoReturn,
     Optional,
     Sequence,
-    Set,
     Tuple,
     Type,
     TypeVar,
@@ -23,8 +22,6 @@ from typing import (
     overload,
 )
 
-from typing_extensions import TypeGuard
-
 TypeOrTupleOfTypes = Union[type, Tuple[type, ...]]
 Numeric = Union[int, float]
 T = TypeVar("T")
@@ -160,7 +157,8 @@ def opt_callable_param(
 def is_callable(obj: object, additional_message: Optional[str] = None) -> Callable:
     if not callable(obj):
         raise CheckError(
-            f"Must be callable. Got {obj}.{additional_message and f' Description: {additional_message}.' or ''}"
+            "Must be callable. Got"
+            f" {obj}.{additional_message and f' Description: {additional_message}.' or ''}"
         )
     return obj
 
@@ -169,13 +167,15 @@ def is_callable(obj: object, additional_message: Optional[str] = None) -> Callab
 # ##### CLASS
 # ########################
 
+T_Type = TypeVar("T_Type", bound=type)
+
 
 def class_param(
-    obj: object,
+    obj: T_Type,
     param_name: str,
     superclass: Optional[type] = None,
     additional_message: Optional[str] = None,
-) -> type:
+) -> T_Type:
     if not isinstance(obj, type):
         raise _param_class_mismatch_exception(
             obj, param_name, superclass, False, additional_message
@@ -1068,8 +1068,8 @@ def two_dim_mapping_param(
 def not_none_param(
     obj: Optional[T], param_name: str, additional_message: Optional[str] = None
 ) -> T:
-    additional_message = " " + additional_message if additional_message else ""
     if obj is None:
+        additional_message = " " + additional_message if additional_message else ""
         raise _param_invariant_exception(
             param_name, f"Param {param_name} cannot be none.{additional_message}"
         )
@@ -1488,8 +1488,8 @@ def opt_tuple_param(
     additional_message: Optional[str] = None,
 ) -> Tuple[Any, ...]:
     """Ensures argument obj is a tuple or None; in the latter case, instantiates an empty tuple
-    and returns it."""
-
+    and returns it.
+    """
     if obj is not None and not isinstance(obj, tuple):  # type: ignore
         raise _param_type_mismatch_exception(obj, tuple, param_name, additional_message)
 
@@ -1588,10 +1588,10 @@ def _check_tuple_items(
         len_type = len(of_shape)
         if not len_tuple == len_type:
             raise CheckError(
-                f"Tuple mismatches type: tuple had {len_tuple} members but type had " f"{len_type}"
+                f"Tuple mismatches type: tuple had {len_tuple} members but type had {len_type}"
             )
 
-        for (i, obj) in enumerate(obj_tuple):
+        for i, obj in enumerate(obj_tuple):
             of_shape_i = of_shape[i]
             if not isinstance(obj, of_shape_i):
                 if isinstance(obj, type):
@@ -1611,6 +1611,51 @@ def _check_tuple_items(
     return obj_tuple
 
 
+def tuple_elem(
+    ddict: Mapping,
+    key: str,
+    of_type: Optional[TypeOrTupleOfTypes] = None,
+    additional_message: Optional[str] = None,
+) -> Tuple:
+    dict_param(ddict, "ddict")
+    str_param(key, "key")
+    opt_class_param(of_type, "of_type")
+
+    value = ddict.get(key)
+
+    if isinstance(value, tuple):
+        if not of_type:
+            return value
+
+        return _check_iterable_items(value, of_type, "tuple")
+
+    raise _element_check_error(key, value, ddict, tuple, additional_message)
+
+
+def opt_tuple_elem(
+    ddict: Mapping,
+    key: str,
+    of_type: Optional[TypeOrTupleOfTypes] = None,
+    additional_message: Optional[str] = None,
+) -> Tuple:
+    dict_param(ddict, "ddict")
+    str_param(key, "key")
+    opt_class_param(of_type, "of_type")
+
+    value = ddict.get(key)
+
+    if value is None:
+        return tuple()
+
+    if isinstance(value, tuple):
+        if not of_type:
+            return value
+
+        return _check_iterable_items(value, of_type, "tuple")
+
+    raise _element_check_error(key, value, ddict, tuple, additional_message)
+
+
 # ###################################################################################################
 # ##### OTHER CHECKS
 # ###################################################################################################
@@ -1694,13 +1739,13 @@ def _param_type_mismatch_exception(
     if isinstance(ttype, tuple):
         type_names = sorted([t.__name__ for t in ttype])
         return ParameterCheckError(
-            f'Param "{param_name}" is not one of {type_names}. Got {repr(obj)} which is type {type(obj)}.'
-            f"{additional_message}"
+            f'Param "{param_name}" is not one of {type_names}. Got {repr(obj)} which is type'
+            f" {type(obj)}.{additional_message}"
         )
     else:
         return ParameterCheckError(
-            f'Param "{param_name}" is not a {ttype.__name__}. Got {repr(obj)} which is type {type(obj)}.'
-            f"{additional_message}"
+            f'Param "{param_name}" is not a {ttype.__name__}. Got {repr(obj)} which is type'
+            f" {type(obj)}.{additional_message}"
         )
 
 
@@ -1715,8 +1760,8 @@ def _param_class_mismatch_exception(
     opt_clause = optional and "be None or" or ""
     subclass_clause = superclass and f"that inherits from {superclass.__name__}" or ""
     return ParameterCheckError(
-        f'Param "{param_name}" must {opt_clause}be a class{subclass_clause}. Got {repr(obj)} of type {type(obj)}.'
-        f"{additional_message}"
+        f'Param "{param_name}" must {opt_clause}be a class{subclass_clause}. Got {repr(obj)} of'
+        f" type {type(obj)}.{additional_message}"
     )
 
 
@@ -1731,7 +1776,8 @@ def _type_mismatch_error(
     repr_obj = repr(obj)
     additional_message = " " + additional_message if additional_message else ""
     return CheckError(
-        f"Object {repr_obj} is {type_message}. Got {repr_obj} with type {type(obj)}.{additional_message}"
+        f"Object {repr_obj} is {type_message}. Got {repr_obj} with type"
+        f" {type(obj)}.{additional_message}"
     )
 
 
@@ -1758,7 +1804,6 @@ def _check_iterable_items(
     obj_iter: T_Iterable, of_type: TypeOrTupleOfTypes, collection_name: str = "iterable"
 ) -> T_Iterable:
     for obj in obj_iter:
-
         if not isinstance(obj, of_type):
             if isinstance(obj, type):
                 additional_message = (
@@ -1767,8 +1812,8 @@ def _check_iterable_items(
             else:
                 additional_message = ""
             raise CheckError(
-                f"Member of {collection_name} mismatches type. Expected {of_type}. Got {repr(obj)} of type "
-                f"{type(obj)}.{additional_message}"
+                f"Member of {collection_name} mismatches type. Expected {of_type}. Got"
+                f" {repr(obj)} of type {type(obj)}.{additional_message}"
             )
 
     return obj_iter
@@ -1790,13 +1835,14 @@ def _check_mapping_entries(
     for key, value in obj.items():
         if key_type and not key_check(key, key_type):
             raise CheckError(
-                f"Key in {mapping_type.__name__} mismatches type. Expected {repr(key_type)}. Got {repr(key)}"
+                f"Key in {mapping_type.__name__} mismatches type. Expected {repr(key_type)}. Got"
+                f" {repr(key)}"
             )
 
         if value_type and not value_check(value, value_type):
             raise CheckError(
-                f"Value in {mapping_type.__name__} mismatches expected type for key {key}. Expected value "
-                f"of type {repr(value_type)}. Got value {value} of type {type(value)}."
+                f"Value in {mapping_type.__name__} mismatches expected type for key {key}. Expected"
+                f" value of type {repr(value_type)}. Got value {value} of type {type(value)}."
             )
 
     return obj
