@@ -11,8 +11,6 @@ from .config_type import Array, ConfigType, ConfigTypeKind
 if TYPE_CHECKING:
     from dagster._config import Field
 
-    from .snap import ConfigTypeSnap
-
 
 def all_optional_type(config_type: ConfigType) -> bool:
     check.inst_param(config_type, "config_type", ConfigType)
@@ -75,7 +73,6 @@ def _add_hash(m, string):
 
 
 def compute_fields_hash(fields, description, field_aliases=None):
-
     m = hashlib.sha1()  # so that hexdigest is 40, not 64 bytes
     if description:
         _add_hash(m, ":description: " + description)
@@ -162,6 +159,7 @@ class Map(ConfigType):
     type checked values. Unlike :py:class:`Shape` and :py:class:`Permissive`, scalar
     keys other than strings can be used, and unlike :py:class:`Permissive`, all
     values are type checked.
+
     Args:
         key_type (type):
             The type of keys this map can contain. Must be a scalar type.
@@ -308,7 +306,7 @@ class Selector(_ConfigHasFields):
             if 'haw' in context.op_config:
                 return 'Aloha {whom}!'.format(whom=context.op_config['haw']['whom'])
             if 'cn' in context.op_config:
-                return '你好，{whom}!'.format(whom=context.op_config['cn']['whom'])
+                return '你好, {whom}!'.format(whom=context.op_config['cn']['whom'])
             if 'en' in context.op_config:
                 return 'Hello, {whom}!'.format(whom=context.op_config['en']['whom'])
     """
@@ -371,7 +369,6 @@ def _expand_fields_dict(
 
 
 def expand_list(original_root: object, the_list: Sequence[object], stack: List[str]) -> Array:
-
     if len(the_list) != 1:
         raise DagsterInvalidConfigDefinitionError(
             original_root, the_list, stack, "List must be of length 1"
@@ -392,7 +389,6 @@ def expand_list(original_root: object, the_list: Sequence[object], stack: List[s
 
 
 def expand_map(original_root: object, the_dict: Mapping[object, object], stack: List[str]) -> Map:
-
     if len(the_dict) != 1:
         raise DagsterInvalidConfigDefinitionError(
             original_root, the_dict, stack, "Map dict must be of length 1"
@@ -414,9 +410,8 @@ def expand_map(original_root: object, the_dict: Mapping[object, object], stack:
             original_root,
             the_dict,
             stack,
-            "Map must have a single value and contain a valid type i.e. {{str: int}}. Got item {}".format(
-                repr(the_dict[key])
-            ),
+            "Map must have a single value and contain a valid type i.e. {{str: int}}. Got item {}"
+            .format(repr(the_dict[key])),
         )
 
     return Map(key_type, inner_type)
