@@ -19,7 +19,6 @@ from typing import (
 )
 
 import dagster._check as check
-from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.metadata import MetadataUserInput, RawMetadataValue
 from dagster._core.selector.subset_selector import AssetSelectionData
 from dagster._utils.backcompat import ExperimentalWarning
@@ -37,7 +36,7 @@ if TYPE_CHECKING:
     from dagster._core.definitions.assets import AssetsDefinition, SourceAsset
     from dagster._core.definitions.job_definition import JobDefinition
     from dagster._core.definitions.partition_mapping import PartitionMapping
-    from dagster._core.definitions.resolved_asset_defs import ResolvedAssetDependencies
+    from dagster._core.definitions.resolved_asset_deps import ResolvedAssetDependencies
     from dagster._core.execution.context.output import OutputContext
 
     from .partition import PartitionedConfig, PartitionsDefinition
@@ -207,7 +206,6 @@ def _get_dependency_node_output_handles(
     belong in the same graph-backed asset node.
 
     Arguments:
-
     outputs_by_graph_handle: A mapping of every graph node handle to a dictionary with each out
         name as a key and a NodeOutputHandle containing the op output name and op node handle
     non_asset_inputs_by_node_handle: A mapping of all node handles to all upstream node handles
@@ -296,7 +294,6 @@ def asset_key_to_dep_node_handles(
     2. A mapping of each asset key to a list of node output handles that are upstream dependencies of the asset.
 
     Arguments:
-
     graph_def: The graph definition of the job, where each top level node is an asset.
     assets_defs_by_node_handle: A mapping of each node handle to the asset definition for that node.
     """
@@ -396,7 +393,7 @@ def _asset_mappings_for_node(
 ]:
     """
     Recursively iterate through all the sub-nodes of a Node to find any ops with asset info
-    encoded on their inputs/outputs
+    encoded on their inputs/outputs.
     """
     check.inst_param(node_def, "node_def", NodeDefinition)
     check.opt_inst_param(node_handle, "node_handle", NodeHandle)
@@ -476,6 +473,7 @@ class AssetLayer:
     _asset_defs_by_key: Mapping[AssetKey, "AssetsDefinition"]
     _asset_defs_by_node_handle: Mapping[NodeHandle, Set["AssetsDefinition"]]
     _io_manager_keys_by_asset_key: Mapping[AssetKey, str]
+    _partition_mappings_by_asset_dep: Mapping[Tuple[NodeHandle, AssetKey], "PartitionMapping"]
 
     def __init__(
         self,
@@ -491,6 +489,9 @@ class AssetLayer:
         node_output_handles_to_dep_asset_keys: Optional[
             Mapping[NodeOutputHandle, Set[AssetKey]]
         ] = None,
+        partition_mappings_by_asset_dep: Optional[
+            Mapping[Tuple[NodeHandle, AssetKey], "PartitionMapping"]
+        ] = None,
     ):
         from dagster._core.definitions import SourceAsset
 
@@ -549,9 +550,11 @@ class AssetLayer:
             value_type=set,
         )
 
+        self._partition_mappings_by_asset_dep = partition_mappings_by_asset_dep or {}
+
     @staticmethod
     def from_graph(graph_def: GraphDefinition) -> "AssetLayer":
-        """Scrape asset info off of InputDefinition/OutputDefinition instances"""
+        """Scrape asset info off of InputDefinition/OutputDefinition instances."""
         check.inst_param(graph_def, "graph_def", GraphDefinition)
         asset_by_input, asset_by_output, asset_deps, io_manager_by_asset = _asset_mappings_for_node(
             graph_def, None
@@ -590,6 +593,7 @@ class AssetLayer:
         io_manager_by_asset: Dict[AssetKey, str] = {
             source_asset.key: source_asset.get_io_manager_key() for source_asset in source_assets
         }
+        partition_mappings_by_asset_dep: Dict[Tuple[NodeHandle, AssetKey], "PartitionMapping"] = {}
 
         (
             dep_node_handles_by_asset_key,
@@ -614,6 +618,12 @@ class AssetLayer:
                 for node_input_handle in node_input_handles:
                     asset_key_by_input[node_input_handle] = resolved_asset_key
 
+                partition_mapping = assets_def.get_partition_mapping_for_input(input_name)
+                if partition_mapping is not None:
+                    partition_mappings_by_asset_dep[
+                        (node_handle, resolved_asset_key)
+                    ] = partition_mapping
+
             for output_name, asset_key in assets_def.node_keys_by_output_name.items():
                 # resolve graph output to the op output it comes from
                 inner_output_def, inner_node_handle = assets_def.node_def.resolve_output_to_origin(
@@ -667,6 +677,7 @@ class AssetLayer:
             source_asset_defs=source_assets,
             io_manager_keys_by_asset_key=io_manager_by_asset,
             node_output_handles_to_dep_asset_keys=node_output_handles_to_dep_asset_keys,
+            partition_mappings_by_asset_dep=partition_mappings_by_asset_dep,
         )
 
     @property
@@ -793,13 +804,10 @@ class AssetLayer:
 
         return None
 
-    def partition_mapping_for_asset_dep(
-        self, asset_key: AssetKey, upstream_asset_key: AssetKey
+    def partition_mapping_for_node_input(
+        self, node_handle: NodeHandle, upstream_asset_key: AssetKey
     ) -> Optional["PartitionMapping"]:
-        assets_def = self._assets_defs_by_key.get(asset_key)
-        if not assets_def:
-            return None
-        return assets_def.get_partition_mapping(upstream_asset_key)
+        return self._partition_mappings_by_asset_dep.get((node_handle.root, upstream_asset_key))
 
     def downstream_dep_assets(self, node_handle: NodeHandle, output_name: str) -> Set[AssetKey]:
         """
@@ -868,9 +876,11 @@ def build_asset_selection_job(
         for asset in included_assets:
             check.invariant(
                 asset.partitions_def == partitions_def or asset.partitions_def is None,
-                f"Assets defined for node '{asset.node_def.name}' have a partitions_def of "
-                f"{asset.partitions_def}, but job '{name}' has non-matching partitions_def of "
-                f"{partitions_def}.",
+                (
+                    f"Assets defined for node '{asset.node_def.name}' have a partitions_def of "
+                    f"{asset.partitions_def}, but job '{name}' has non-matching partitions_def of "
+                    f"{partitions_def}."
+                ),
             )
 
     # We should disallow simultaneous selection of assets and source assets (but for
