@@ -24,7 +24,6 @@ class AssetSelection(ABC):
     AssetSelections are typically used with :py:func:`define_asset_job`.
 
     Examples:
-
         .. code-block:: python
 
             # Select all assets in group "marketing":
@@ -58,7 +57,23 @@ class AssetSelection(ABC):
     @public  # type: ignore
     @staticmethod
     def keys(*asset_keys: CoercibleToAssetKey) -> "KeysAssetSelection":
-        """Returns a selection that includes assets with any of the provided keys."""
+        """
+        Returns a selection that includes assets with any of the provided keys.
+
+        Examples:
+            .. code-block:: python
+
+                AssetSelection.keys(AssetKey(["a"]))
+
+                AssetSelection.keys("a")
+
+                AssetSelection.keys(AssetKey(["a"]), AssetKey(["b"]))
+
+                AssetSelection.keys("a", "b")
+
+                asset_key_list = [AssetKey(["a"]), AssetKey(["b"])]
+                AssetSelection.keys(*asset_key_list)
+        """
         _asset_keys = [
             AssetKey.from_user_string(key)
             if isinstance(key, str)
@@ -70,7 +85,7 @@ class AssetSelection(ABC):
     @public  # type: ignore
     @staticmethod
     def groups(*group_strs) -> "GroupsAssetSelection":
-        """Returns a selection that includes assets that belong to any of the provided groups"""
+        """Returns a selection that includes assets that belong to any of the provided groups."""
         check.tuple_param(group_strs, "group_strs", of_type=str)
         return GroupsAssetSelection(*group_strs)
 
@@ -122,7 +137,8 @@ class AssetSelection(ABC):
         assets within the original asset selection.
 
         A sink asset is an asset that has no downstream dependencies within the asset selection.
-        The sink asset can have downstream dependencies outside of the asset selection."""
+        The sink asset can have downstream dependencies outside of the asset selection.
+        """
         return SinkAssetSelection(self)
 
     @public  # type: ignore
@@ -132,7 +148,8 @@ class AssetSelection(ABC):
         assets within the original asset selection.
 
         A source asset is an asset that has no upstream dependencies within the asset selection.
-        The source asset can have downstream dependencies outside of the asset selection."""
+        The source asset can have downstream dependencies outside of the asset selection.
+        """
         return SourceAssetSelection(self)
 
     def __or__(self, other: "AssetSelection") -> "OrAssetSelection":
@@ -150,7 +167,6 @@ class AssetSelection(ABC):
     def resolve(
         self, all_assets: Union[Sequence[Union[AssetsDefinition, SourceAsset]], AssetGraph]
     ) -> AbstractSet[AssetKey]:
-
         if isinstance(all_assets, AssetGraph):
             asset_graph = all_assets
         else:
