@@ -1,11 +1,14 @@
 from abc import ABC, abstractmethod
-from typing import Any, Callable, Mapping, Optional, TypeVar, Union
+from typing import Any, Callable, Optional, TypeVar, Union
 
 from typing_extensions import Self
 
-from dagster import Field
-from dagster import _check as check
+from dagster import (
+    Field,
+    _check as check,
+)
 from dagster._config import EvaluateValueResult
+from dagster._config.config_schema import UserConfigSchema
 
 from .definition_config_schema import (
     CoercableToConfigSchema,
@@ -93,7 +96,6 @@ class AnonymousConfigurableDefinition(ConfigurableDefinition):
 
         Returns (ConfigurableDefinition): A configured version of this object.
         """
-
         new_config_schema = ConfiguredDefinitionConfigSchema(
             self, convert_user_facing_definition_config_schema(config_schema), config_or_config_fn
         )
@@ -116,7 +118,7 @@ class NamedConfigurableDefinition(ConfigurableDefinition):
         self,
         config_or_config_fn: Any,
         name: str,
-        config_schema: Optional[Mapping[str, Any]] = None,
+        config_schema: Optional[UserConfigSchema] = None,
         description: Optional[str] = None,
     ) -> Self:  # type: ignore [valid-type] # (until mypy supports Self)
         """
@@ -142,7 +144,6 @@ class NamedConfigurableDefinition(ConfigurableDefinition):
 
         Returns (ConfigurableDefinition): A configured version of this object.
         """
-
         name = check.str_param(name, "name")
 
         new_config_schema = ConfiguredDefinitionConfigSchema(
@@ -168,12 +169,12 @@ def _check_configurable_param(configurable: ConfigurableDefinition) -> None:
         not isinstance(configurable, PendingNodeInvocation),
         "configurable",
         (
-            "You have invoked `configured` on a PendingNodeInvocation (an intermediate type), which is "
-            "produced by aliasing or tagging a solid definition. To configure a solid, you must "
-            "call `configured` on either a SolidDefinition and CompositeSolidDefinition. To fix "
-            "this error, make sure to call `configured` on the definition object *before* using "
-            "the `tag` or `alias` methods. For usage examples, see "
-            "https://docs.dagster.io/concepts/configuration/configured"
+            "You have invoked `configured` on a PendingNodeInvocation (an intermediate type), which"
+            " is produced by aliasing or tagging a solid definition. To configure a solid, you must"
+            " call `configured` on either a SolidDefinition and CompositeSolidDefinition. To fix"
+            " this error, make sure to call `configured` on the definition object *before* using"
+            " the `tag` or `alias` methods. For usage examples, see"
+            " https://docs.dagster.io/concepts/configuration/configured"
         ),
     )
     check.inst_param(
@@ -181,10 +182,10 @@ def _check_configurable_param(configurable: ConfigurableDefinition) -> None:
         "configurable",
         ConfigurableDefinition,
         (
-            "Only the following types can be used with the `configured` method: ResourceDefinition, "
-            "ExecutorDefinition, CompositeSolidDefinition, SolidDefinition, and LoggerDefinition. "
-            "For usage examples of `configured`, see "
-            "https://docs.dagster.io/concepts/configuration/configured"
+            "Only the following types can be used with the `configured` method: ResourceDefinition,"
+            " ExecutorDefinition, CompositeSolidDefinition, SolidDefinition, and LoggerDefinition."
+            " For usage examples of `configured`, see"
+            " https://docs.dagster.io/concepts/configuration/configured"
         ),
     )
 
@@ -196,7 +197,7 @@ T_Configurable = TypeVar(
 
 def configured(
     configurable: T_Configurable,
-    config_schema: Optional[Mapping[str, Any]] = None,
+    config_schema: Optional[UserConfigSchema] = None,
     **kwargs: Any,
 ) -> Callable[[object], T_Configurable]:
     """
