@@ -1,5 +1,7 @@
+import collections.abc
 from abc import ABC, abstractmethod
-from typing import NamedTuple, Optional, cast
+from collections import defaultdict
+from typing import Collection, Mapping, NamedTuple, Optional, Union, cast
 
 import dagster._check as check
 from dagster._annotations import experimental, public
@@ -7,9 +9,14 @@ from dagster._core.definitions.multi_dimensional_partitions import (
     MultiPartitionKey,
     MultiPartitionsDefinition,
 )
-from dagster._core.definitions.partition import PartitionsDefinition, PartitionsSubset
+from dagster._core.definitions.partition import (
+    PartitionsDefinition,
+    PartitionsSubset,
+    StaticPartitionsDefinition,
+)
 from dagster._core.definitions.partition_key_range import PartitionKeyRange
 from dagster._serdes import whitelist_for_serdes
+from dagster._utils.cached_method import cached_method
 
 
 class PartitionMapping(ABC):
@@ -320,6 +327,125 @@ class SingleDimensionDependencyMapping(PartitionMapping):
         return downstream_partitions_def.empty_subset().with_partition_keys(set(matching_keys))
 
 
+class StaticPartitionMapping(PartitionMapping):
+    """
+    Define an explicit correspondence between two StaticPartitionsDefinitions.
+
+    Args:
+        downstream_partition_keys_by_upstream_partition_key (Dict[str, str | Collection[str]]):
+          The single or multi-valued correspondence from upstream keys to downstream keys.
+    """
+
+    def __init__(
+        self,
+        downstream_partition_keys_by_upstream_partition_key: Mapping[
+            str, Union[str, Collection[str]]
+        ],
+    ):
+        check.mapping_param(
+            downstream_partition_keys_by_upstream_partition_key,
+            "downstream_partition_keys_by_upstream_partition_key",
+            key_type=str,
+            value_type=(str, collections.abc.Collection),
+        )
+
+        # cache forward and reverse mappings
+        self._mapping = defaultdict(set)
+        for (
+            upstream_key,
+            downstream_keys,
+        ) in downstream_partition_keys_by_upstream_partition_key.items():
+            self._mapping[upstream_key] = (
+                {downstream_keys} if isinstance(downstream_keys, str) else set(downstream_keys)
+            )
+
+        self._inverse_mapping = defaultdict(set)
+        for upstream_key, downstream_keys in self._mapping.items():
+            for downstream_key in downstream_keys:
+                self._inverse_mapping[downstream_key].add(upstream_key)
+
+    @cached_method
+    def _check_upstream(self, *, upstream_partitions_def: PartitionsDefinition):
+        """
+        validate that the mapping from upstream to downstream is only defined on upstream keys
+        """
+        check.inst(
+            upstream_partitions_def,
+            StaticPartitionsDefinition,
+            "StaticPartitionMapping can only be defined between two StaticPartitionsDefinitions",
+        )
+        upstream_keys = upstream_partitions_def.get_partition_keys()
+        extra_keys = set(self._mapping.keys()).difference(upstream_keys)
+        if extra_keys:
+            raise ValueError(
+                f"mapping source partitions not in the upstream partitions definition: {extra_keys}"
+            )
+
+    @cached_method
+    def _check_downstream(self, *, downstream_partitions_def: PartitionsDefinition):
+        """
+        validate that the mapping from upstream to downstream only maps to downstream keys
+        """
+        check.inst(
+            downstream_partitions_def,
+            StaticPartitionsDefinition,
+            "StaticPartitionMapping can only be defined between two StaticPartitionsDefinitions",
+        )
+        downstream_keys = downstream_partitions_def.get_partition_keys()
+        extra_keys = set(self._inverse_mapping.keys()).difference(downstream_keys)
+        if extra_keys:
+            raise ValueError(
+                "mapping target partitions not in the downstream partitions definition:"
+                f" {extra_keys}"
+            )
+
+    def get_downstream_partitions_for_partitions(
+        self,
+        upstream_partitions_subset: PartitionsSubset,
+        downstream_partitions_def: PartitionsDefinition,
+    ) -> PartitionsSubset:
+        self._check_downstream(downstream_partitions_def=downstream_partitions_def)
+
+        downstream_subset = downstream_partitions_def.empty_subset()
+        downstream_keys = set()
+        for key in upstream_partitions_subset.get_partition_keys():
+            downstream_keys.update(self._mapping[key])
+        return downstream_subset.with_partition_keys(downstream_keys)
+
+    def get_upstream_partitions_for_partitions(
+        self,
+        downstream_partitions_subset: Optional[PartitionsSubset],
+        upstream_partitions_def: PartitionsDefinition,
+    ) -> PartitionsSubset:
+        self._check_upstream(upstream_partitions_def=upstream_partitions_def)
+
+        upstream_subset = upstream_partitions_def.empty_subset()
+        if downstream_partitions_subset is None:
+            return upstream_subset
+
+        upstream_keys = set()
+        for key in downstream_partitions_subset.get_partition_keys():
+            upstream_keys.update(self._inverse_mapping[key])
+
+        return upstream_subset.with_partition_keys(upstream_keys)
+
+    def get_upstream_partitions_for_partition_range(
+        self,
+        downstream_partition_key_range: Optional[PartitionKeyRange],
+        downstream_partitions_def: Optional[PartitionsDefinition],
+        upstream_partitions_def: PartitionsDefinition,
+    ) -> PartitionKeyRange:
+        raise NotImplementedError()
+
+    def get_downstream_partitions_for_partition_range(
+        self,
+        upstream_partition_key_range: PartitionKeyRange,
+        downstream_partitions_def: Optional[PartitionsDefinition],
+        upstream_partitions_def: PartitionsDefinition,
+    ) -> PartitionKeyRange:
+        raise NotImplementedError()
+
+
 def infer_partition_mapping(
     partition_mapping: Optional[PartitionMapping], partitions_def: Optional[PartitionsDefinition]
 ) -> PartitionMapping:
@@ -338,5 +464,6 @@ def get_builtin_partition_mapping_types():
         AllPartitionMapping,
         IdentityPartitionMapping,
         LastPartitionMapping,
+        StaticPartitionMapping,
         TimeWindowPartitionMapping,
     )
