@@ -28,7 +28,10 @@ def build_schedule_from_partitioned_job(
     """
     check.invariant(
         not (day_of_week and day_of_month),
-        "Cannot provide both day_of_month and day_of_week parameter to build_schedule_from_partitioned_job.",
+        (
+            "Cannot provide both day_of_month and day_of_week parameter to"
+            " build_schedule_from_partitioned_job."
+        ),
     )
     partitions_def = job.partitions_def
     if partitions_def is None:
