@@ -42,7 +42,6 @@ from .utils import check_valid_name
 
 if TYPE_CHECKING:
     from dagster._core.definitions.repository_definition import RepositoryDefinition
-    from dagster._core.storage.event_log.base import EventLogRecord
 
 
 @whitelist_for_serdes
@@ -132,7 +131,8 @@ class SensorEvaluationContext:
         if not self._instance:
             if not self._instance_ref:
                 raise DagsterInvariantViolationError(
-                    "Attempted to initialize dagster instance, but no instance reference was provided."
+                    "Attempted to initialize dagster instance, but no instance reference was"
+                    " provided."
                 )
             self._instance = self._exit_stack.enter_context(
                 DagsterInstance.from_ref(self._instance_ref)
@@ -215,11 +215,8 @@ class SensorEvaluationContext:
         return self._log_key
 
 
-# Preserve SensorExecutionContext for backcompat so type annotations don't break.
-SensorExecutionContext = SensorEvaluationContext
-
 RawSensorEvaluationFunctionReturn = Union[
-    Iterator[Union[SkipReason, RunRequest]],
+    Iterator[Union[SkipReason, RunRequest, PipelineRunReaction]],
     Sequence[RunRequest],
     SkipReason,
     RunRequest,
@@ -241,7 +238,7 @@ def is_context_provided(
 
 
 class SensorDefinition:
-    """Define a sensor that initiates a set of runs based on some external state
+    """Define a sensor that initiates a set of runs based on some external state.
 
     Args:
         evaluation_fn (Callable[[SensorEvaluationContext]]): The core evaluation function for the
@@ -340,7 +337,6 @@ class SensorDefinition:
         )
 
     def __call__(self, *args, **kwargs):
-
         if is_context_provided(self._raw_fn):
             if len(args) + len(kwargs) == 0:
                 raise DagsterInvalidInvocationError(
@@ -415,11 +411,11 @@ class SensorDefinition:
 
         Args:
             context (SensorEvaluationContext): The context with which to evaluate this sensor.
+
         Returns:
             SensorExecutionData: Contains list of run requests, or skip message if present.
 
         """
-
         context = check.inst_param(context, "context", SensorEvaluationContext)
 
         result = list(self._evaluation_fn(context))
@@ -525,7 +521,8 @@ class SensorDefinition:
     def job_name(self) -> Optional[str]:
         if len(self._targets) > 1:
             raise DagsterInvalidInvocationError(
-                f"Cannot use `job_name` property for sensor {self.name}, which targets multiple jobs."
+                f"Cannot use `job_name` property for sensor {self.name}, which targets multiple"
+                " jobs."
             )
         return self._targets[0].pipeline_name
 
@@ -628,14 +625,12 @@ def build_sensor_context(
         repository_def (Optional[RepositoryDefinition]): The repository that the sensor belongs to.
 
     Examples:
-
         .. code-block:: python
 
             context = build_sensor_context()
             my_sensor(context)
 
     """
-
     check.opt_inst_param(instance, "instance", DagsterInstance)
     check.opt_str_param(cursor, "cursor")
     check.opt_str_param(repository_name, "repository_name")
@@ -669,12 +664,13 @@ def _run_requests_with_base_asset_jobs(
             ).resolve(asset_graph)
             if unexpected_asset_keys:
                 raise DagsterInvalidSubsetError(
-                    f"RunRequest includes asset keys that are not part of sensor's asset_selection: {unexpected_asset_keys}"
+                    "RunRequest includes asset keys that are not part of sensor's asset_selection:"
+                    f" {unexpected_asset_keys}"
                 )
         else:
             asset_keys = outer_asset_selection.resolve(asset_graph)
 
-        base_job = context.repository_def.get_base_job_for_assets(asset_keys)
+        base_job = context.repository_def.get_implicit_job_def_for_assets(asset_keys)
         result.append(
             run_request.with_replaced_attrs(
                 job_name=base_job.name, asset_selection=list(asset_keys)
