@@ -34,7 +34,8 @@ from .system import StepExecutionContext
 
 
 class AbstractComputeExecutionContext(ABC):  # pylint: disable=no-init
-    """Base class for solid context implemented by SolidExecutionContext and DagstermillExecutionContext"""
+    """Base class for solid context implemented by SolidExecutionContext and DagstermillExecutionContext.
+    """
 
     @abstractmethod
     def has_tag(self, key) -> bool:
@@ -90,15 +91,13 @@ class OpExecutionContext(AbstractComputeExecutionContext):
     purposes, use :py:func:`dagster.build_op_context`.
 
     Example:
+        .. code-block:: python
 
-    .. code-block:: python
-
-        from dagster import op
-
-        @op
-        def hello_world(context: OpExecutionContext):
-            context.log.info("Hello, world!")
+            from dagster import op
 
+            @op
+            def hello_world(context: OpExecutionContext):
+                context.log.info("Hello, world!")
     """
 
     __slots__ = ["_step_execution_context"]
@@ -124,18 +123,18 @@ class OpExecutionContext(AbstractComputeExecutionContext):
 
     @property
     def pipeline_run(self) -> DagsterRun:
-        """PipelineRun: The current pipeline run"""
+        """PipelineRun: The current pipeline run."""
         return self._step_execution_context.pipeline_run
 
     @property
     def run(self) -> DagsterRun:
-        """DagsterRun: The current run"""
+        """DagsterRun: The current run."""
         return cast(DagsterRun, self.pipeline_run)
 
     @public  # type: ignore
     @property
     def instance(self) -> DagsterInstance:
-        """DagsterInstance: The current Dagster instance"""
+        """DagsterInstance: The current Dagster instance."""
         return self._step_execution_context.instance
 
     @public  # type: ignore
@@ -144,13 +143,11 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """dagster.utils.forked_pdb.ForkedPdb: Gives access to pdb debugging from within the op.
 
         Example:
+            .. code-block:: python
 
-        .. code-block:: python
-
-            @op
-            def debug(context):
-                context.pdb.set_trace()
-
+                @op
+                def debug(context):
+                    context.pdb.set_trace()
         """
         if self._pdb is None:
             self._pdb = ForkedPdb()
@@ -164,8 +161,8 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         :meta private:
         """
         raise DagsterInvalidPropertyError(
-            "You have attempted to access the file manager which has been moved to resources in 0.10.0. "
-            "Please access it via `context.resources.file_manager` instead."
+            "You have attempted to access the file manager which has been moved to resources in"
+            " 0.10.0. Please access it via `context.resources.file_manager` instead."
         )
 
     @public  # type: ignore
@@ -274,7 +271,7 @@ class OpExecutionContext(AbstractComputeExecutionContext):
     @public  # type: ignore
     @property
     def has_partition_key(self) -> bool:
-        """Whether the current run is a partitioned run"""
+        """Whether the current run is a partitioned run."""
         return self._step_execution_context.has_partition_key
 
     @public  # type: ignore
@@ -320,7 +317,6 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         selected_asset_keys = self.selected_asset_keys
         selected_outputs = set()
         for output_name in self.op.output_dict.keys():
-
             asset_info = self.job_def.asset_layer.asset_info_for_output(
                 self.solid_handle, output_name
             )
@@ -376,7 +372,9 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         deprecation_warning(
             "OpExecutionContext.output_asset_partitions_time_window",
             "1.0.0",
-            additional_warn_txt="Use OpExecutionContext.asset_partitions_time_window_for_output instead.",
+            additional_warn_txt=(
+                "Use OpExecutionContext.asset_partitions_time_window_for_output instead."
+            ),
         )
 
         return self.asset_partitions_time_window_for_output(output_name)
@@ -415,7 +413,8 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         )
         if result is None:
             raise DagsterInvariantViolationError(
-                f"Attempting to access partitions def for asset {asset_key}, but it is not partitioned"
+                f"Attempting to access partitions def for asset {asset_key}, but it is not"
+                " partitioned"
             )
 
         return result
@@ -429,7 +428,8 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         )
         if result is None:
             raise DagsterInvariantViolationError(
-                f"Attempting to access partitions def for asset {asset_key}, but it is not partitioned"
+                f"Attempting to access partitions def for asset {asset_key}, but it is not"
+                " partitioned"
             )
 
         return result
@@ -444,7 +444,8 @@ class OpExecutionContext(AbstractComputeExecutionContext):
     @public
     def asset_partition_keys_for_input(self, input_name: str) -> Sequence[str]:
         """Returns a list of the partition keys of the upstream asset corresponding to the
-        given input."""
+        given input.
+        """
         return self.asset_partitions_def_for_input(input_name).get_partition_keys_in_range(
             self._step_execution_context.asset_partition_key_range_for_input(input_name)
         )
@@ -504,7 +505,6 @@ class OpExecutionContext(AbstractComputeExecutionContext):
             def log_materialization(context):
                 context.log_event(AssetMaterialization("foo"))
         """
-
         if isinstance(event, (AssetMaterialization, Materialization)):
             self._events.append(
                 DagsterEvent.asset_materialization(
@@ -588,7 +588,6 @@ class OpExecutionContext(AbstractComputeExecutionContext):
         """
         Which retry attempt is currently executing i.e. 0 for initial attempt, 1 for first retry, etc.
         """
-
         return self._step_execution_context.previous_attempt_count
 
     def describe_op(self):
