@@ -7,7 +7,6 @@ from dagster._core.execution.plan.plan import ExecutionPlan
 def validate_reexecution_memoization(
     plan_context: IPlanContext, execution_plan: ExecutionPlan
 ) -> None:
-
     parent_run_id = plan_context.pipeline_run.parent_run_id
     check.opt_str_param(parent_run_id, "parent_run_id")
 
@@ -22,7 +21,7 @@ def validate_reexecution_memoization(
         return
 
     raise DagsterInvariantViolationError(
-        "Cannot perform reexecution with in-memory io managers.\n"
-        "To enable reexecution, you can set a persistent io manager, such as the "
-        'fs_io_manager, in the resource_defs argument on your job: resource_defs={"io_manager": fs_io_manager}'
+        "Cannot perform reexecution with in-memory io managers.\nTo enable reexecution, you can set"
+        " a persistent io manager, such as the fs_io_manager, in the resource_defs argument on your"
+        ' job: resource_defs={"io_manager": fs_io_manager}'
     )
