@@ -36,6 +36,7 @@ from dagster._core.snap import ExecutionPlanSnapshot
 from dagster._core.snap.execution_plan_snapshot import ExecutionStepSnap
 from dagster._core.utils import toposort
 from dagster._serdes import create_snapshot_id
+from dagster._utils import iter_to_list
 from dagster._utils.cached_method import cached_method
 from dagster._utils.schedules import schedule_execution_time_iterator
 
@@ -88,7 +89,8 @@ class ExternalRepository:
             self._deferred_snapshots = True
             if ref_to_data_fn is None:
                 check.failed(
-                    "ref_to_data_fn is required when ExternalRepositoryData is loaded with deferred snapshots"
+                    "ref_to_data_fn is required when ExternalRepositoryData is loaded with deferred"
+                    " snapshots"
                 )
 
             self._ref_to_data_fn = ref_to_data_fn
@@ -128,7 +130,7 @@ class ExternalRepository:
         return self._external_schedules[schedule_name]
 
     def get_external_schedules(self) -> Sequence[ExternalSchedule]:
-        return self._external_schedules.values()
+        return iter_to_list(self._external_schedules.values())
 
     @property
     @cached_method
@@ -145,7 +147,7 @@ class ExternalRepository:
         return self._external_sensors[sensor_name]
 
     def get_external_sensors(self) -> Sequence[ExternalSensor]:
-        return self._external_sensors.values()
+        return iter_to_list(self._external_sensors.values())
 
     @property
     @cached_method
@@ -164,7 +166,7 @@ class ExternalRepository:
         return self._external_partition_sets[partition_set_name]
 
     def get_external_partition_sets(self) -> Sequence[ExternalPartitionSet]:
-        return self._external_partition_sets.values()
+        return iter_to_list(self._external_partition_sets.values())
 
     def has_external_job(self, job_name: str) -> bool:
         return job_name in self._job_map
@@ -562,15 +564,17 @@ class ExternalSchedule:
         return self.get_external_origin().get_id()
 
     @property
-    def selector_id(self) -> str:
-        return create_snapshot_id(
-            InstigatorSelector(
-                self.handle.location_name,
-                self.handle.repository_name,
-                self._external_schedule_data.name,
-            )
+    def selector(self) -> InstigatorSelector:
+        return InstigatorSelector(
+            self.handle.location_name,
+            self.handle.repository_name,
+            self._external_schedule_data.name,
         )
 
+    @property
+    def selector_id(self) -> str:
+        return create_snapshot_id(self.selector)
+
     @property
     def default_status(self) -> DefaultScheduleStatus:
         return (
@@ -686,15 +690,17 @@ class ExternalSensor:
         return self.get_external_origin().get_id()
 
     @property
-    def selector_id(self) -> str:
-        return create_snapshot_id(
-            InstigatorSelector(
-                self.handle.location_name,
-                self.handle.repository_name,
-                self._external_sensor_data.name,
-            )
+    def selector(self) -> InstigatorSelector:
+        return InstigatorSelector(
+            self.handle.location_name,
+            self.handle.repository_name,
+            self._external_sensor_data.name,
         )
 
+    @property
+    def selector_id(self) -> str:
+        return create_snapshot_id(self.selector)
+
     def get_current_instigator_state(
         self, stored_state: Optional["InstigatorState"]
     ) -> InstigatorState:
@@ -783,7 +789,7 @@ class ExternalPartitionSet:
         # Partition sets from older versions of Dagster as well as partition sets using
         # a DynamicPartitionsDefinition require calling out to user code to compute the partition
         # names
-        return self._external_partition_set_data.external_partitions_data != None
+        return self._external_partition_set_data.external_partitions_data is not None
 
     def get_partition_names(self) -> Sequence[str]:
         check.invariant(self.has_partition_name_data())
