@@ -1,4 +1,4 @@
-"""wipe schedules table for 0.10.0
+"""wipe schedules table for 0.10.0.
 
 Revision ID: 140198fdfe65
 Revises: b22f16781a7c
@@ -6,9 +6,8 @@ Create Date: 2021-01-11 22:16:50.896040
 
 """
 from alembic import op
-from sqlalchemy import inspect
-
 from dagster._core.storage.migration.utils import get_currently_upgrading_instance, has_table
+from sqlalchemy import inspect
 
 # alembic magic breaks pylint
 # pylint: disable=no-member
