@@ -1,4 +1,4 @@
-"""convert start end times format
+"""convert start end times format.
 
 Revision ID: 130b087bc274
 Revises: b37316bf5584
@@ -6,7 +6,6 @@ Create Date: 2022-02-01 15:21:22.257972
 
 """
 from alembic import op
-
 from dagster._core.storage.migration.utils import (
     add_run_record_start_end_timestamps,
     drop_run_record_start_end_timestamps,
