@@ -312,7 +312,6 @@ class SqlEventLogStorage(EventLogStorage):
             )
             and event.dagster_event.step_materialization_data.materialization.tags
         ):
-
             if not self.has_table(AssetEventTagsTable.name):
                 # If tags table does not exist, silently exit. This is to support OSS
                 # users who have not yet run the migration to create the table.
@@ -389,11 +388,7 @@ class SqlEventLogStorage(EventLogStorage):
         check.str_param(run_id, "run_id")
         check.opt_str_param(cursor, "cursor")
 
-        check.invariant(
-            not of_type
-            or isinstance(of_type, DagsterEventType)
-            or isinstance(of_type, (frozenset, set))
-        )
+        check.invariant(not of_type or isinstance(of_type, (DagsterEventType, frozenset, set)))
 
         dagster_event_types = (
             {of_type}
@@ -473,7 +468,7 @@ class SqlEventLogStorage(EventLogStorage):
             .where(
                 db.and_(
                     SqlEventLogStorageTable.c.run_id == run_id,
-                    SqlEventLogStorageTable.c.dagster_event_type != None,
+                    SqlEventLogStorageTable.c.dagster_event_type != None,  # noqa: E711
                 )
             )
             .group_by("dagster_event_type")
@@ -535,7 +530,7 @@ class SqlEventLogStorage(EventLogStorage):
         raw_event_query = (
             db.select([SqlEventLogStorageTable.c.event])
             .where(SqlEventLogStorageTable.c.run_id == run_id)
-            .where(SqlEventLogStorageTable.c.step_key != None)
+            .where(SqlEventLogStorageTable.c.step_key != None)  # noqa: E711
             .where(
                 SqlEventLogStorageTable.c.dagster_event_type.in_(
                     [
@@ -587,12 +582,12 @@ class SqlEventLogStorage(EventLogStorage):
             print_fn(f"Finished data migration: {migration_name}")
 
     def reindex_events(self, print_fn=None, force=False):
-        """Call this method to run any data migrations across the event_log table"""
+        """Call this method to run any data migrations across the event_log table."""
         for migration_name, migration_fn in EVENT_LOG_DATA_MIGRATIONS.items():
             self._apply_migration(migration_name, migration_fn, print_fn, force)
 
     def reindex_assets(self, print_fn=None, force=False):
-        """Call this method to run any data migrations across the asset_keys table"""
+        """Call this method to run any data migrations across the asset_keys table."""
         for migration_name, migration_fn in ASSET_DATA_MIGRATIONS.items():
             self._apply_migration(migration_name, migration_fn, print_fn, force)
 
@@ -627,7 +622,7 @@ class SqlEventLogStorage(EventLogStorage):
         removed_asset_key_query = (
             db.select([SqlEventLogStorageTable.c.asset_key])
             .where(SqlEventLogStorageTable.c.run_id == run_id)
-            .where(SqlEventLogStorageTable.c.asset_key != None)
+            .where(SqlEventLogStorageTable.c.asset_key != None)  # noqa: E711
             .group_by(SqlEventLogStorageTable.c.asset_key)
         )
 
@@ -692,7 +687,8 @@ class SqlEventLogStorage(EventLogStorage):
         """Utility method to test representation of the record in the SQL table.  Returns all of
         the columns stored in the event log storage (as opposed to the deserialized `EventLogEntry`).
         This allows checking that certain fields are extracted to support performant lookups (e.g.
-        extracting `step_key` for fast filtering)"""
+        extracting `step_key` for fast filtering).
+        """
         with self.run_connection(run_id=run_id) as conn:
             query = (
                 db.select([SqlEventLogStorageTable])
@@ -708,7 +704,7 @@ class SqlEventLogStorage(EventLogStorage):
         query = (
             db.select([1])
             .where(SecondaryIndexMigrationTable.c.name == name)
-            .where(SecondaryIndexMigrationTable.c.migration_completed != None)
+            .where(SecondaryIndexMigrationTable.c.migration_completed != None)  # noqa: E711
             .limit(1)
         )
         with self.index_connection() as conn:
@@ -973,6 +969,7 @@ class SqlEventLogStorage(EventLogStorage):
             results = conn.execute(query).fetchall()
 
         events = {}
+        record_id = None
         try:
             for (
                 record_id,
@@ -1002,7 +999,7 @@ class SqlEventLogStorage(EventLogStorage):
                     last_run_id=row[3],
                     asset_details=AssetDetails.from_db_string(row[4]),
                     cached_status=AssetStatusCacheValue.from_db_string(row[5])
-                    if self.has_asset_key_col("cached_status_data")
+                    if self.can_cache_asset_status_data()
                     else None,
                 ),
             )
@@ -1238,7 +1235,7 @@ class SqlEventLogStorage(EventLogStorage):
     def update_asset_cached_status_data(
         self, asset_key: AssetKey, cache_values: "AssetStatusCacheValue"
     ) -> None:
-        if self.has_asset_key_col("cached_status_data"):
+        if self.can_cache_asset_status_data():
             with self.index_connection() as conn:
                 conn.execute(
                     AssetKeyTable.update()  # pylint: disable=no-value-for-parameter
@@ -1548,7 +1545,7 @@ class SqlEventLogStorage(EventLogStorage):
                     wipe_timestamp=utc_datetime_from_timestamp(wipe_timestamp),
                 )
             )
-        if self.has_asset_key_col("cached_status_data"):
+        if self.can_cache_asset_status_data():
             values.update(dict(cached_status_data=None))
         return values
 
@@ -1591,7 +1588,7 @@ class SqlEventLogStorage(EventLogStorage):
                             [asset_key.to_string(legacy=True) for asset_key in asset_keys]
                         ),
                     ),
-                    SqlEventLogStorageTable.c.partition != None,
+                    SqlEventLogStorageTable.c.partition != None,  # noqa: E711
                     SqlEventLogStorageTable.c.dagster_event_type
                     == DagsterEventType.ASSET_MATERIALIZATION.value,
                 )
@@ -1617,8 +1614,9 @@ class SqlEventLogStorage(EventLogStorage):
 
 
 def _get_from_row(row, column):
-    """utility function for extracting a column from a sqlalchemy row proxy, since '_asdict' is not
-    supported in sqlalchemy 1.3"""
+    """Utility function for extracting a column from a sqlalchemy row proxy, since '_asdict' is not
+    supported in sqlalchemy 1.3.
+    """
     if not row.has_key(column):
         return None
     return row[column]
