@@ -18,7 +18,7 @@ from .temp_file_manager import TempfileManager
 
 # pylint: disable=no-init
 class FileHandle(ABC):
-    """A reference to a file as manipulated by a FileManager
+    """A reference to a file as manipulated by a FileManager.
 
     Subclasses may handle files that are resident on the local file system, in an object store, or
     in any arbitrary place where a file can be stored.
@@ -175,53 +175,50 @@ def local_file_manager(init_context):
     Implements the :py:class:`~dagster._core.storage.file_manager.FileManager` API.
 
     Examples:
+        .. code-block:: python
 
-    .. code-block:: python
+            import tempfile
 
-        import tempfile
-
-        from dagster import job, local_file_manager, op
+            from dagster import job, local_file_manager, op
 
 
-        @op(required_resource_keys={"file_manager"})
-        def write_files(context):
-            fh_1 = context.resources.file_manager.write_data(b"foo")
+            @op(required_resource_keys={"file_manager"})
+            def write_files(context):
+                fh_1 = context.resources.file_manager.write_data(b"foo")
 
-            with tempfile.NamedTemporaryFile("w+") as fd:
-                fd.write("bar")
-                fd.seek(0)
-                fh_2 = context.resources.file_manager.write(fd, mode="w", ext=".txt")
+                with tempfile.NamedTemporaryFile("w+") as fd:
+                    fd.write("bar")
+                    fd.seek(0)
+                    fh_2 = context.resources.file_manager.write(fd, mode="w", ext=".txt")
 
-            return (fh_1, fh_2)
+                return (fh_1, fh_2)
 
 
-        @op(required_resource_keys={"file_manager"})
-        def read_files(context, file_handles):
-            fh_1, fh_2 = file_handles
-            assert context.resources.file_manager.read_data(fh_2) == b"bar"
-            fd = context.resources.file_manager.read(fh_2, mode="r")
-            assert fd.read() == "foo"
-            fd.close()
+            @op(required_resource_keys={"file_manager"})
+            def read_files(context, file_handles):
+                fh_1, fh_2 = file_handles
+                assert context.resources.file_manager.read_data(fh_2) == b"bar"
+                fd = context.resources.file_manager.read(fh_2, mode="r")
+                assert fd.read() == "foo"
+                fd.close()
 
 
-        @job(resource_defs={"file_manager": local_file_manager})
-        def files_pipeline():
-            read_files(write_files())
+            @job(resource_defs={"file_manager": local_file_manager})
+            def files_pipeline():
+                read_files(write_files())
 
-    Or to specify the file directory:
+        Or to specify the file directory:
 
-    .. code-block:: python
-
-        @job(
-            resource_defs={
-                "file_manager": local_file_manager.configured({"base_dir": "/my/base/dir"})
-            }
-        )
-        def files_pipeline():
-            read_files(write_files())
+        .. code-block:: python
 
+            @job(
+                resource_defs={
+                    "file_manager": local_file_manager.configured({"base_dir": "/my/base/dir"})
+                }
+            )
+            def files_pipeline():
+                read_files(write_files())
     """
-
     return LocalFileManager(
         base_dir=init_context.resource_config.get(
             "base_dir", os.path.join(init_context.instance.storage_directory(), "file_manager")
