@@ -16,6 +16,8 @@ from typing import (
     Union,
 )
 
+from typing_extensions import Self
+
 import dagster._check as check
 from dagster._annotations import public
 from dagster._core.definitions.events import AssetKey
@@ -35,7 +37,6 @@ from dagster._serdes.serdes import (
 
 from .tags import (
     BACKFILL_ID_TAG,
-    PARTITION_NAME_TAG,
     PARTITION_SET_TAG,
     REPOSITORY_LABEL_TAG,
     RESUME_RETRY_TAG,
@@ -44,7 +45,10 @@ from .tags import (
 )
 
 if TYPE_CHECKING:
-    from dagster._core.definitions.repository_definition import RepositoryLoadData
+    from dagster._core.definitions.partition import (
+        Partition,
+        PartitionSetDefinition,
+    )
     from dagster._core.host_representation.origin import ExternalPipelineOrigin
 
 
@@ -226,7 +230,6 @@ def pipeline_run_from_storage(
     has_repository_load_data=None,
     **kwargs,
 ):
-
     # serdes log
     # * removed reexecution_config - serdes logic expected to strip unknown keys so no need to preserve
     # * added pipeline_snapshot_id
@@ -257,11 +260,9 @@ def pipeline_run_from_storage(
     if selector:
         check.invariant(
             pipeline_name is None or selector.name == pipeline_name,
-            (
-                "Conflicting pipeline name {pipeline_name} in arguments to PipelineRun: "
-                "selector was passed with pipeline {selector_pipeline}".format(
-                    pipeline_name=pipeline_name, selector_pipeline=selector.name
-                )
+            "Conflicting pipeline name {pipeline_name} in arguments to PipelineRun: "
+            "selector was passed with pipeline {selector_pipeline}".format(
+                pipeline_name=pipeline_name, selector_pipeline=selector.name
             ),
         )
         if pipeline_name is None:
@@ -269,11 +270,9 @@ def pipeline_run_from_storage(
 
         check.invariant(
             solids_to_execute is None or set(selector.solid_subset) == solids_to_execute,
-            (
-                "Conflicting solids_to_execute {solids_to_execute} in arguments to PipelineRun: "
-                "selector was passed with subset {selector_subset}".format(
-                    solids_to_execute=solids_to_execute, selector_subset=selector.solid_subset
-                )
+            "Conflicting solids_to_execute {solids_to_execute} in arguments to PipelineRun: "
+            "selector was passed with subset {selector_subset}".format(
+                solids_to_execute=solids_to_execute, selector_subset=selector.solid_subset
             ),
         )
         # for old runs that only have selector but no solids_to_execute
@@ -430,7 +429,7 @@ class DagsterRun(
             ),
         )
 
-    def with_status(self, status):
+    def with_status(self, status: DagsterRunStatus) -> Self:  # type: ignore  # fmt: skip
         if status == DagsterRunStatus.QUEUED:
             # Placing this with the other imports causes a cyclic import
             # https://github.com/dagster-io/dagster/issues/3181
@@ -444,16 +443,16 @@ class DagsterRun(
 
         return self._replace(status=status)
 
-    def with_job_origin(self, origin):
+    def with_job_origin(self, origin: "ExternalPipelineOrigin") -> Self:  # type: ignore  # fmt: skip
         from dagster._core.host_representation.origin import ExternalPipelineOrigin
 
         check.inst_param(origin, "origin", ExternalPipelineOrigin)
         return self._replace(external_pipeline_origin=origin)
 
-    def with_mode(self, mode):
+    def with_mode(self, mode: str) -> Self:  # type: ignore  # fmt: skip
         return self._replace(mode=mode)
 
-    def with_tags(self, tags):
+    def with_tags(self, tags: Mapping[str, str]) -> Self:  # type: ignore  # fmt: skip
         return self._replace(tags=tags)
 
     def get_root_run_id(self):
@@ -483,12 +482,12 @@ class DagsterRun(
 
     @public  # type: ignore
     @property
-    def is_success(self):
+    def is_success(self) -> bool:
         return self.status == DagsterRunStatus.SUCCESS
 
     @public  # type: ignore
     @property
-    def is_failure(self):
+    def is_failure(self) -> bool:
         return self.status == DagsterRunStatus.FAILURE
 
     @public  # type: ignore
@@ -498,11 +497,11 @@ class DagsterRun(
 
     @public  # type: ignore
     @property
-    def is_resume_retry(self):
+    def is_resume_retry(self) -> bool:
         return self.tags.get(RESUME_RETRY_TAG) == "true"
 
     @property
-    def previous_run_id(self):
+    def previous_run_id(self) -> Optional[str]:
         # Compat
         return self.parent_run_id
 
@@ -512,30 +511,23 @@ class DagsterRun(
         return self.pipeline_name
 
     @staticmethod
-    def tags_for_schedule(schedule):
+    def tags_for_schedule(schedule) -> Mapping[str, str]:
         return {SCHEDULE_NAME_TAG: schedule.name}
 
     @staticmethod
-    def tags_for_sensor(sensor):
+    def tags_for_sensor(sensor) -> Mapping[str, str]:
         return {SENSOR_NAME_TAG: sensor.name}
 
     @staticmethod
-    def tags_for_backfill_id(backfill_id):
+    def tags_for_backfill_id(backfill_id: str) -> Mapping[str, str]:
         return {BACKFILL_ID_TAG: backfill_id}
 
     @staticmethod
-    def tags_for_partition_set(partition_set, partition):
-        from dagster._core.definitions.multi_dimensional_partitions import (
-            MultiPartitionKey,
-            get_tags_from_multi_partition_key,
-        )
-
+    def tags_for_partition_set(
+        partition_set: "PartitionSetDefinition", partition: "Partition"
+    ) -> Mapping[str, str]:
         tags = {PARTITION_SET_TAG: partition_set.name}
-        if isinstance(partition.name, MultiPartitionKey):
-            tags.update(get_tags_from_multi_partition_key(partition.name))
-        else:
-            tags[PARTITION_NAME_TAG] = partition.name
-
+        tags.update(partition_set.partitions_def.get_tags_for_partition_key(partition.name))
         return tags
 
 
