@@ -9,11 +9,13 @@ from dagster._serdes import deserialize_as
 from ...execution.job_backfill import PartitionBackfill
 from ..pipeline_run import DagsterRun, DagsterRunStatus
 from ..runs.base import RunStorage
-from ..runs.schema import BulkActionsTable, RunTagsTable, RunsTable
+from ..runs.schema import BulkActionsTable, RunsTable, RunTagsTable
 from ..tags import PARTITION_NAME_TAG, PARTITION_SET_TAG, REPOSITORY_LABEL_TAG
 
 RUN_PARTITIONS = "run_partitions"
-RUN_START_END = "run_start_end_overwritten"  # was run_start_end, but renamed to overwrite bad timestamps written
+RUN_START_END = (  # was run_start_end, but renamed to overwrite bad timestamps written
+    "run_start_end_overwritten"
+)
 RUN_REPO_LABEL_TAGS = "run_repo_label_tags"
 BULK_ACTION_TYPES = "bulk_action_types"
 
@@ -105,7 +107,6 @@ def migrate_run_start_end(storage, print_fn=None):
     """
     Utility method that updates the start and end times of historical runs using the completed event log.
     """
-
     if print_fn:
         print_fn("Querying run and event log storage.")
 
