@@ -53,7 +53,8 @@ from dagster._serdes import (
     serialize_dagster_namedtuple,
 )
 from dagster._seven import JSONDecodeError
-from dagster._utils import merge_dicts, utc_datetime_from_timestamp
+from dagster._utils import utc_datetime_from_timestamp
+from dagster._utils.merger import merge_dicts
 
 from ..pipeline_run import (
     DagsterRun,
@@ -71,8 +72,8 @@ from .schema import (
     DaemonHeartbeatsTable,
     InstanceInfo,
     KeyValueStoreTable,
-    RunTagsTable,
     RunsTable,
+    RunTagsTable,
     SecondaryIndexMigrationTable,
     SnapshotsTable,
 )
@@ -84,7 +85,7 @@ class SnapshotType(Enum):
 
 
 class SqlRunStorage(RunStorage):  # pylint: disable=no-init
-    """Base class for SQL based run storages"""
+    """Base class for SQL based run storages."""
 
     @abstractmethod
     def connect(self):
@@ -188,7 +189,6 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
             kwargs["end_time"] = now.timestamp()
 
         with self.connect() as conn:
-
             conn.execute(
                 RunsTable.update()  # pylint: disable=no-value-for-parameter
                 .where(RunsTable.c.run_id == run_id)
@@ -219,8 +219,7 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
         order_by: Optional[str],
         ascending: Optional[bool],
     ):
-        """Helper function to deal with cursor/limit pagination args"""
-
+        """Helper function to deal with cursor/limit pagination args."""
         if cursor:
             cursor_query = db.select([RunsTable.c.id]).where(RunsTable.c.run_id == cursor)
             query = query.where(RunsTable.c.id < cursor_query)
@@ -595,7 +594,10 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
         root_run = self.get_run_by_id(root_run_id)
         if not root_run:
             raise DagsterRunNotFoundError(
-                f"Run id {root_run_id} set as root run id for run {run_id} was not found in instance.",
+                (
+                    f"Run id {root_run_id} set as root run id for run {run_id} was not found in"
+                    " instance."
+                ),
                 invalid_run_id=root_run_id,
             )
 
@@ -969,7 +971,7 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
         query = (
             db.select([1])
             .where(SecondaryIndexMigrationTable.c.name == migration_name)
-            .where(SecondaryIndexMigrationTable.c.migration_completed != None)
+            .where(SecondaryIndexMigrationTable.c.migration_completed != None)  # noqa: E711
             .limit(1)
         )
         with self.connect() as conn:
@@ -1012,7 +1014,6 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
 
     def add_daemon_heartbeat(self, daemon_heartbeat: DaemonHeartbeat):
         with self.connect() as conn:
-
             # insert, or update if already present
             try:
                 conn.execute(
@@ -1035,7 +1036,6 @@ class SqlRunStorage(RunStorage):  # pylint: disable=no-init
                 )
 
     def get_daemon_heartbeats(self) -> Mapping[str, DaemonHeartbeat]:
-
         with self.connect() as conn:
             rows = conn.execute(db.select(DaemonHeartbeatsTable.columns))
             heartbeats = []
