@@ -29,7 +29,7 @@ from .schema import InstigatorsTable, JobTable, JobTickTable, SecondaryIndexMigr
 
 
 class SqlScheduleStorage(ScheduleStorage):
-    """Base class for SQL backed schedule storage"""
+    """Base class for SQL backed schedule storage."""
 
     @abstractmethod
     def connect(self):
@@ -348,7 +348,8 @@ class SqlScheduleStorage(ScheduleStorage):
                 return InstigatorTick(tick_id, tick_data)
             except db.exc.IntegrityError as exc:
                 raise DagsterInvariantViolationError(
-                    f"Unable to insert InstigatorTick for job {tick_data.instigator_name} in storage"
+                    f"Unable to insert InstigatorTick for job {tick_data.instigator_name} in"
+                    " storage"
                 ) from exc
 
     def update_tick(self, tick):
@@ -425,7 +426,7 @@ class SqlScheduleStorage(ScheduleStorage):
         query = (
             db.select([1])
             .where(SecondaryIndexMigrationTable.c.name == migration_name)
-            .where(SecondaryIndexMigrationTable.c.migration_completed != None)
+            .where(SecondaryIndexMigrationTable.c.migration_completed != None)  # noqa: E711
             .limit(1)
         )
         with self.connect() as conn:
