@@ -95,7 +95,7 @@ def run_migrations_offline(context, config, target_metadata):
     except DatabaseError as exc:
         # This is to deal with concurrent execution -- if this table already exists thanks to a
         # race with another process, we are fine and can continue.
-        if not "table alembic_version already exists" in str(exc):
+        if "table alembic_version already exists" not in str(exc):
             raise
 
 
@@ -126,7 +126,7 @@ def run_migrations_online(context, config, target_metadata):
         except DatabaseError as exc:
             # This is to deal with concurrent execution -- if this table already exists thanks to a
             # race with another process, we are fine and can continue.
-            if not "table alembic_version already exists" in str(exc):
+            if "table alembic_version already exists" not in str(exc):
                 raise
 
 
@@ -138,6 +138,7 @@ def run_migrations_online(context, config, target_metadata):
 MYSQL_DATE_PRECISION: int = 6
 MYSQL_FLOAT_PRECISION: int = 32
 
+
 # datetime issue fix from here: https://stackoverflow.com/questions/29711102/sqlalchemy-mysql-millisecond-or-microsecond-precision/29723278
 @compiles(db.DateTime, "mysql")
 def compile_datetime_and_add_precision_mysql(_element, _compiler, **_kw):
@@ -145,7 +146,7 @@ def compile_datetime_and_add_precision_mysql(_element, _compiler, **_kw):
 
 
 class get_current_timestamp(db.sql.expression.FunctionElement):  # pylint: disable=abstract-method
-    """Like CURRENT_TIMESTAMP, but has the same semantics on MySQL, Postgres, and Sqlite"""
+    """Like CURRENT_TIMESTAMP, but has the same semantics on MySQL, Postgres, and Sqlite."""
 
     type = db.types.DateTime()
 
@@ -169,7 +170,8 @@ def add_precision_to_mysql_timestamps(_element, _compiler, **_kw):
 def add_precision_to_mysql_floats(_element, _compiler, **_kw):
     """Forces floats to have minimum precision of 32, which converts the underlying type to be a
     double.  This is necessary because the default precision of floats is too low for some types,
-    including unix timestamps, resulting in truncated values in MySQL"""
+    including unix timestamps, resulting in truncated values in MySQL.
+    """
     return f"FLOAT({MYSQL_FLOAT_PRECISION})"
 
 
@@ -177,7 +179,8 @@ def add_precision_to_mysql_floats(_element, _compiler, **_kw):
 def add_precision_to_mysql_FLOAT(_element, _compiler, **_kw):
     """Forces floats to have minimum precision of 32, which converts the underlying type to be a
     double.  This is necessary because the default precision of floats is too low for some types,
-    including unix timestamps, resulting in truncated values in MySQL"""
+    including unix timestamps, resulting in truncated values in MySQL.
+    """
     return f"FLOAT({MYSQL_FLOAT_PRECISION})"
 
 
