@@ -1,7 +1,6 @@
 import asyncio
 import os
 import re
-import signal
 import sys
 import tempfile
 import time
@@ -13,9 +12,12 @@ from typing import Any, Generator, Mapping, NamedTuple, Optional, Sequence, Type
 import pendulum
 import yaml
 
-from dagster import Permissive, Shape
-from dagster import _check as check
-from dagster import fs_io_manager
+from dagster import (
+    Permissive,
+    Shape,
+    _check as check,
+    fs_io_manager,
+)
 from dagster._config import Array, Field
 from dagster._core.definitions.decorators.graph_decorator import graph
 from dagster._core.errors import DagsterUserCodeUnreachableError
@@ -33,9 +35,10 @@ from dagster._core.workspace.load_target import WorkspaceLoadTarget
 from dagster._legacy import ModeDefinition, pipeline, solid
 from dagster._serdes import ConfigurableClass
 from dagster._seven.compat.pendulum import create_pendulum_time, mock_pendulum_timezone
-from dagster._utils import Counter, merge_dicts, traced, traced_counter
+from dagster._utils import Counter, get_terminate_signal, traced, traced_counter
 from dagster._utils.error import serializable_error_info_from_exc_info
 from dagster._utils.log import configure_loggers
+from dagster._utils.merger import merge_dicts
 
 T_NamedTuple = TypeVar("T_NamedTuple", bound=NamedTuple)
 
@@ -54,7 +57,7 @@ def assert_namedtuples_equal(
 ) -> None:
     exclude_fields = exclude_fields or []
     for field in type(t1)._fields:
-        if not field in exclude_fields:
+        if field not in exclude_fields:
             assert getattr(t1, field) == getattr(t2, field)
 
 
@@ -99,7 +102,7 @@ def nesting_graph_pipeline(depth, num_children, *args, **kwargs):
 @contextmanager
 def environ(env):
     """Temporarily set environment variables inside the context manager and
-    fully restore previous environment afterwards
+    fully restore previous environment afterwards.
     """
     previous_values = {key: os.getenv(key) for key in env}
     for key, value in env.items():
@@ -136,7 +139,7 @@ def instance_for_test(
 
     Args:
         overrides (Optional[Mapping[str, Any]]):
-            Config to provide to instance (config format follows that typically found in an `instance.yaml` file).
+            Config to provide to instance (config format follows that typically found in an `instance.yaml` file).
         set_dagster_home (Optional[bool]):
             If set to True, the `$DAGSTER_HOME` environment variable will be
             overridden to be the directory used by this instance for the
@@ -503,12 +506,6 @@ class TestSecretsLoader(SecretsLoader, ConfigurableClass):
         return TestSecretsLoader(inst_data=inst_data, **config_value)
 
 
-def get_terminate_signal():
-    if sys.platform == "win32":
-        return signal.SIGTERM
-    return signal.SIGKILL
-
-
 def get_crash_signals():
     return [get_terminate_signal()]
 
@@ -558,7 +555,8 @@ def create_test_daemon_workspace_context(
     workspace_load_target: WorkspaceLoadTarget,
     instance: DagsterInstance,
 ):
-    """Creates a DynamicWorkspace suitable for passing into a DagsterDaemon loop when running tests."""
+    """Creates a DynamicWorkspace suitable for passing into a DagsterDaemon loop when running tests.
+    """
     from dagster._daemon.controller import create_daemon_grpc_server_registry
 
     configure_loggers()
