@@ -5,7 +5,9 @@ import warnings
 from abc import ABC, abstractmethod
 from contextlib import ExitStack
 from itertools import count
-from typing import TYPE_CHECKING, Dict, Mapping, Optional, Sequence, Union, cast
+from typing import TYPE_CHECKING, Dict, Mapping, Optional, Sequence, Set, Union, cast
+
+from typing_extensions import Self
 
 import dagster._check as check
 from dagster._core.errors import (
@@ -37,7 +39,11 @@ from dagster._core.instance import DagsterInstance
 from dagster._utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
 
 from .load_target import WorkspaceLoadTarget
-from .permissions import PermissionResult, get_user_permissions
+from .permissions import (
+    PermissionResult,
+    get_location_scoped_user_permissions,
+    get_user_permissions,
+)
 from .workspace import (
     IWorkspace,
     WorkspaceLocationEntry,
@@ -103,10 +109,26 @@ class BaseWorkspaceRequestContext(IWorkspace):
     def permissions(self) -> Mapping[str, PermissionResult]:
         pass
 
+    @abstractmethod
+    def permissions_for_location(self, location_name: str) -> Mapping[str, PermissionResult]:
+        pass
+
+    def has_permission_for_location(self, permission: str, location_name: str) -> bool:
+        if self.has_repository_location_name(location_name):
+            permissions = self.permissions_for_location(location_name)
+            return permissions[permission].enabled
+
+        # if not in workspace, fall back to the global permissions across all code locations
+        return self.has_permission(permission)
+
     @abstractmethod
     def has_permission(self, permission: str) -> bool:
         pass
 
+    @abstractmethod
+    def was_permission_checked(self, permission: str) -> bool:
+        pass
+
     @property
     def show_instance_config(self) -> bool:
         return True
@@ -150,7 +172,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
         ]
 
     def has_repository_location_error(self, name: str) -> bool:
-        return self.get_repository_location_error(name) != None
+        return self.get_repository_location_error(name) is not None
 
     def get_repository_location_error(self, name: str) -> Optional[SerializableErrorInfo]:
         entry = self.get_location_entry(name)
@@ -161,7 +183,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
 
     def has_repository_location(self, name: str) -> bool:
         location_entry = self.get_location_entry(name)
-        return bool(location_entry and location_entry.repository_location != None)
+        return bool(location_entry and location_entry.repository_location is not None)
 
     def is_reload_supported(self, name: str) -> bool:
         entry = self.get_location_entry(name)
@@ -180,7 +202,7 @@ class BaseWorkspaceRequestContext(IWorkspace):
     def shutdown_repository_location(self, name: str):
         self.process_context.shutdown_repository_location(name)
 
-    def reload_workspace(self) -> "BaseWorkspaceRequestContext":
+    def reload_workspace(self) -> Self:  # type: ignore  # fmt: skip
         self.process_context.reload_workspace()
         return self.process_context.create_request_context()
 
@@ -286,6 +308,7 @@ class WorkspaceRequestContext(BaseWorkspaceRequestContext):
         self._version = version
         self._source = source
         self._read_only = read_only
+        self._checked_permissions: Set[str] = set()
 
     @property
     def instance(self) -> DagsterInstance:
@@ -319,20 +342,30 @@ class WorkspaceRequestContext(BaseWorkspaceRequestContext):
     def permissions(self) -> Mapping[str, PermissionResult]:
         return get_user_permissions(self._read_only)
 
+    def permissions_for_location(self, location_name: str) -> Mapping[str, PermissionResult]:
+        return get_location_scoped_user_permissions(self._read_only)
+
     def has_permission(self, permission: str) -> bool:
         permissions = self.permissions
         check.invariant(
             permission in permissions, f"Permission {permission} not listed in permissions map"
         )
+        self._checked_permissions.add(permission)
         return permissions[permission].enabled
 
+    def has_permission_for_location(self, permission: str, location_name: str) -> bool:
+        self._checked_permissions.add(permission)
+        return super().has_permission_for_location(permission, location_name)
+
+    def was_permission_checked(self, permission: str) -> bool:
+        return permission in self._checked_permissions
+
     @property
     def source(self) -> Optional[object]:
         """
         The source of the request this WorkspaceRequestContext originated from.
         For example in Dagit this object represents the web request.
         """
-
         return self._source
 
 
@@ -401,6 +434,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
         version: str = "",
         read_only: bool = False,
         grpc_server_registry=None,
+        code_server_log_level="INFO",
     ):
         self._stack = ExitStack()
 
@@ -438,6 +472,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
                     reload_interval=0,
                     heartbeat_ttl=DAGIT_GRPC_SERVER_HEARTBEAT_TTL,
                     startup_timeout=instance.code_server_process_startup_timeout,
+                    log_level=code_server_log_level,
                 )
             )
 
@@ -498,6 +533,9 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
     def permissions(self) -> Mapping[str, PermissionResult]:
         return get_user_permissions(True)
 
+    def permissions_for_location(self, _location_name: str) -> Mapping[str, PermissionResult]:
+        return get_location_scoped_user_permissions(True)
+
     @property
     def version(self) -> str:
         return self._version
@@ -528,8 +566,10 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
                 LocationStateChangeEvent(
                     LocationStateChangeEventType.LOCATION_ERROR,
                     location_name=location_name,
-                    message="Unable to reconnect to server. You can reload the server once it is "
-                    "reachable again",
+                    message=(
+                        "Unable to reconnect to server. You can reload the server once it is "
+                        "reachable again"
+                    ),
                 )
             ),
         )
@@ -670,7 +710,7 @@ class WorkspaceProcessContext(IWorkspaceProcessContext):
         self._stack.close()
 
     def copy_for_test_instance(self, instance: DagsterInstance) -> "WorkspaceProcessContext":
-        """make a copy with a different instance, created for tests"""
+        """make a copy with a different instance, created for tests."""
         return WorkspaceProcessContext(
             instance=instance,
             workspace_load_target=self.workspace_load_target,
