@@ -11,7 +11,7 @@ from dagster._core.host_representation.origin import (
 )
 from dagster._core.instance import DagsterInstance
 from dagster._core.types.loadable_target_origin import LoadableTargetOrigin
-from dagster._utils import load_yaml_from_path
+from dagster._utils.yaml_utils import load_yaml_from_path
 
 from .config_schema import ensure_workspace_config
 
