@@ -136,7 +136,7 @@ def _process_line(file_pointer, sleep_interval=0.1):
 def _poll_process(ipc_process):
     if not ipc_process:
         return
-    if ipc_process.poll() != None:
+    if ipc_process.poll() is not None:
         raise DagsterIPCProtocolError(
             "Process exited with return code {return_code} while waiting for events".format(
                 return_code=ipc_process.returncode
@@ -188,18 +188,24 @@ def ipc_read_event_stream(file_path, timeout=30, ipc_process=None):
 
 
 def open_ipc_subprocess(parts, **kwargs):
-    """Sets new process group flags on Windows to support graceful termination."""
+    """Sets the correct flags to support graceful termination - the new subprocess will be in
+    its own process group so that CTRL-Cing the parent process doesn't immediately interrupt
+    the child process as well.
+    """
     check.list_param(parts, "parts", str)
 
     creationflags = 0
+    preexec_fn = None
     if sys.platform == "win32":
         creationflags = subprocess.CREATE_NEW_PROCESS_GROUP
-    return subprocess.Popen(parts, creationflags=creationflags, **kwargs)
+    else:
+        # Works on all UNIX systems (but not WASI, see: https://docs.python.org/3/library/os.html#os.setpgrp)
+        preexec_fn = os.setpgrp
+    return subprocess.Popen(parts, creationflags=creationflags, preexec_fn=preexec_fn, **kwargs)
 
 
 def interrupt_ipc_subprocess(proc):
-    """Send CTRL_BREAK on Windows, SIGINT on other platforms"""
-
+    """Send CTRL_BREAK on Windows, SIGINT on other platforms."""
     if sys.platform == "win32":
         proc.send_signal(signal.CTRL_BREAK_EVENT)  # pylint: disable=no-member
     else:
@@ -207,7 +213,7 @@ def interrupt_ipc_subprocess(proc):
 
 
 def interrupt_ipc_subprocess_pid(pid):
-    """Send CTRL_BREAK on Windows, SIGINT on other platforms"""
+    """Send CTRL_BREAK on Windows, SIGINT on other platforms."""
     check.int_param(pid, "pid")
 
     if sys.platform == "win32":
