@@ -42,7 +42,8 @@ USED_DATA_TAG = ".dagster/used_data"
 
 class CachingInstanceQueryer:
     """Provides utility functions for querying for asset-materialization related data from the
-    instance which will attempt to limit redundant expensive calls."""
+    instance which will attempt to limit redundant expensive calls.
+    """
 
     def __init__(self, instance: "DagsterInstance"):
         self._instance = instance
@@ -71,6 +72,9 @@ class CachingInstanceQueryer:
 
         return asset_key in self.get_planned_materializations_for_run(run_id=run_id)
 
+    def run_has_tag(self, run_id: str, tag_key: str, tag_value: str) -> bool:
+        return cast(DagsterRun, self._get_run_by_id(run_id)).tags.get(tag_key) == tag_value
+
     def _get_run_by_id(self, run_id: str) -> Optional[DagsterRun]:
         run_record = self._get_run_record_by_id(run_id=run_id)
         if run_record is not None:
@@ -230,7 +234,7 @@ class CachingInstanceQueryer:
         An asset (partition) is considered unreconciled if any of:
         - It has never been materialized
         - One of its parents has been updated more recently than it has
-        - One of its parents is unreconciled
+        - One of its parents is unreconciled.
         """
         latest_materialization_record = self.get_latest_materialization_record(
             asset_partition, None
@@ -282,7 +286,7 @@ class CachingInstanceQueryer:
     def get_known_used_data(
         self, asset_key: AssetKey, record_id: int
     ) -> Dict[AssetKey, Tuple[Optional[int], Optional[float]]]:
-        """Returns the known upstream ids and timestamps stored on the instance"""
+        """Returns the known upstream ids and timestamps stored on the instance."""
         event_log_storage = self._instance.event_log_storage
         if isinstance(event_log_storage, SqlEventLogStorage) and event_log_storage.has_table(
             AssetEventTagsTable.name
@@ -301,18 +305,6 @@ class CachingInstanceQueryer:
             }
         return {}
 
-    def _upstream_subset(
-        self, asset_graph: AssetGraph, start_key: AssetKey, input_keys: AbstractSet[AssetKey]
-    ) -> AbstractSet[AssetKey]:
-        """Helper method which returns the set up keys in the input set which are upstream of start_key"""
-        ret = set()
-        if start_key in input_keys:
-            ret.add(start_key)
-        for upstream_key in asset_graph.upstream_key_iterator(start_key):
-            if upstream_key in input_keys:
-                ret.add(upstream_key)
-        return frozenset(ret)
-
     @cached_method
     def _calculate_used_data(
         self,
@@ -321,81 +313,73 @@ class CachingInstanceQueryer:
         record_id: Optional[int],
         record_timestamp: Optional[float],
         record_tags: Mapping[str, str],
-        required_keys: AbstractSet[AssetKey],
     ) -> Dict[AssetKey, Tuple[Optional[int], Optional[float]]]:
         if record_id is None:
-            return {key: (None, None) for key in required_keys}
+            return {key: (None, None) for key in asset_graph.get_non_source_roots(asset_key)}
+
+        if not asset_graph.has_non_source_parents(asset_key):
+            return {asset_key: (record_id, record_timestamp)}
 
         # grab the existing upstream data times already calculated for this record (if any)
-        known_data = self.get_known_used_data(asset_key, record_id)
-        if asset_key in required_keys:
-            known_data[asset_key] = (record_id, record_timestamp)
+        if asset_graph.freshness_policies_by_key.get(asset_key) is not None:
+            known_data = self.get_known_used_data(asset_key, record_id)
+            if known_data:
+                return known_data
+        else:
+            known_data = {}
 
-        # not all required keys have known values
-        unknown_required_keys = required_keys - set(known_data.keys())
-        if unknown_required_keys:
+        # find the upstream times of each of the parents of this asset
+        for parent_key in asset_graph.get_parents(asset_key):
+            if parent_key in asset_graph.source_asset_keys:
+                continue
 
-            # find the upstream times of each of the parents of this asset
-            for parent_key in asset_graph.get_parents(asset_key):
-                if parent_key in asset_graph.source_asset_keys:
-                    continue
-
-                # the set of required keys which are upstream of this parent
-                upstream_required_keys = self._upstream_subset(
-                    asset_graph, start_key=parent_key, input_keys=unknown_required_keys
+            input_event_pointer_tag = get_input_event_pointer_tag_key(parent_key)
+            if input_event_pointer_tag in record_tags:
+                # get the upstream materialization event which was consumed when producing this
+                # materialization event
+                pointer_tag = record_tags[input_event_pointer_tag]
+                if pointer_tag and pointer_tag != "NULL":
+                    input_record_id = int(pointer_tag)
+                    parent_record = self.get_latest_materialization_record(
+                        parent_key, before_cursor=input_record_id + 1
+                    )
+                else:
+                    parent_record = None
+            else:
+                # if the input event id was not recorded (materialized pre-1.1.0), just grab
+                # the most recent asset materialization for this parent which happened before
+                # the current record
+                parent_record = self.get_latest_materialization_record(
+                    parent_key, before_cursor=record_id
                 )
 
-                input_event_pointer_tag = get_input_event_pointer_tag_key(parent_key)
-                if input_event_pointer_tag in record_tags:
-                    # get the upstream materialization event which was consumed when producing this
-                    # materialization event
-                    pointer_tag = record_tags[input_event_pointer_tag]
-                    if pointer_tag and pointer_tag != "NULL":
-                        input_record_id = int(pointer_tag)
-                        parent_record = self.get_latest_materialization_record(
-                            parent_key, before_cursor=input_record_id + 1
-                        )
-                    else:
-                        parent_record = None
-                else:
-                    # if the input event id was not recorded (materialized pre-1.1.0), just grab
-                    # the most recent asset materialization for this parent which happened before
-                    # the current record
-                    parent_record = self.get_latest_materialization_record(
-                        parent_key, before_cursor=record_id
+            # recurse to find the data times of this parent
+            for key, tup in self._calculate_used_data(
+                asset_graph=asset_graph,
+                asset_key=parent_key,
+                record_id=parent_record.storage_id if parent_record else None,
+                record_timestamp=parent_record.event_log_entry.timestamp if parent_record else None,
+                record_tags=frozendict(
+                    (
+                        parent_record.asset_materialization.tags
+                        if parent_record and parent_record.asset_materialization
+                        else None
                     )
+                    or {}
+                ),
+            ).items():
+                # if root data is missing, this overrides other values
+                if tup == (None, None) or known_data.get(key) == (None, None):
+                    known_data[key] = (None, None)
+                else:
+                    known_data[key] = min(known_data.get(key, tup), tup)
 
-                # recurse to find the data times of this parent
-                for key, tup in self._calculate_used_data(
-                    asset_graph=asset_graph,
-                    asset_key=parent_key,
-                    record_id=parent_record.storage_id if parent_record else None,
-                    record_timestamp=parent_record.event_log_entry.timestamp
-                    if parent_record
-                    else None,
-                    record_tags=frozendict(
-                        (
-                            parent_record.asset_materialization.tags
-                            if parent_record and parent_record.asset_materialization
-                            else None
-                        )
-                        or {}
-                    ),
-                    required_keys=upstream_required_keys,
-                ).items():
-                    # if root data is missing, this overrides other values
-                    if tup == (None, None) or known_data.get(key) == (None, None):
-                        known_data[key] = (None, None)
-                    else:
-                        known_data[key] = min(known_data.get(key, tup), tup)
-
-        return {k: v for k, v in known_data.items() if k in required_keys}
+        return known_data
 
     def get_used_data_times_for_record(
         self,
         asset_graph: AssetGraph,
         record: EventLogRecord,
-        upstream_keys: Optional[AbstractSet[AssetKey]] = None,
     ) -> Mapping[AssetKey, Optional[datetime.datetime]]:
         """Method to enable calculating the timestamps of materializations of upstream assets
         which were relevant to a given AssetMaterialization. These timestamps can be calculated relative
@@ -407,10 +391,9 @@ class CachingInstanceQueryer:
         """
         if record.asset_key is None or record.asset_materialization is None:
             raise DagsterInvariantViolationError(
-                "Can only calculate data times for records with a materialization event and an asset_key."
+                "Can only calculate data times for records with a materialization event and an"
+                " asset_key."
             )
-        if upstream_keys is None:
-            upstream_keys = asset_graph.get_non_source_roots(record.asset_key)
 
         data = self._calculate_used_data(
             asset_graph=asset_graph,
@@ -418,9 +401,9 @@ class CachingInstanceQueryer:
             record_id=record.storage_id,
             record_timestamp=record.event_log_entry.timestamp,
             record_tags=frozendict(record.asset_materialization.tags or {}),
-            required_keys=frozenset(upstream_keys),
         )
-        self.set_known_used_data(record, new_known_data=data)
+        if asset_graph.freshness_policies_by_key.get(record.asset_key) is not None:
+            self.set_known_used_data(record, new_known_data=data)
 
         return {
             key: datetime.datetime.fromtimestamp(timestamp, tz=datetime.timezone.utc)
@@ -445,7 +428,6 @@ class CachingInstanceQueryer:
         current_time: datetime.datetime,
         asset_graph: AssetGraph,
         asset_key: AssetKey,
-        required_keys: AbstractSet[AssetKey],
     ) -> Mapping[AssetKey, Optional[datetime.datetime]]:
         """Returns the upstream data times that a given asset key will be expected to have at the
         completion of the given run.
@@ -470,7 +452,6 @@ class CachingInstanceQueryer:
                     )
                     or {}
                 ),
-                required_keys=required_keys,
             )
             return {
                 key: datetime.datetime.fromtimestamp(timestamp, tz=datetime.timezone.utc)
@@ -481,21 +462,16 @@ class CachingInstanceQueryer:
 
         # if you're here, then this asset is planned, but not materialized
         upstream_data_times: Dict[AssetKey, Optional[datetime.datetime]] = {}
-        if asset_key in required_keys:
+        if not asset_graph.has_non_source_parents(asset_key):
             # in the worst case (data-time wise), this asset gets materialized right now
             upstream_data_times[asset_key] = current_time
 
         for parent_key in asset_graph.get_parents(asset_key):
-            # the set of required keys which are upstream of this parent
-            upstream_required_keys = self._upstream_subset(
-                asset_graph, start_key=parent_key, input_keys=required_keys
-            )
             for upstream_key, upstream_time in self._get_in_progress_data_times_for_key_in_run(
                 run_id=run_id,
                 current_time=current_time,
                 asset_graph=asset_graph,
                 asset_key=parent_key,
-                required_keys=upstream_required_keys,
             ).items():
                 current_value = upstream_data_times.get(upstream_key, upstream_time)
                 if current_value is None or upstream_time is None:
@@ -508,7 +484,6 @@ class CachingInstanceQueryer:
         self,
         asset_graph: AssetGraph,
         asset_key: AssetKey,
-        upstream_keys: AbstractSet[AssetKey],
         current_time: datetime.datetime,
     ) -> Mapping[AssetKey, datetime.datetime]:
         """Returns a mapping containing the maximum upstream data time that the input asset will
@@ -520,17 +495,14 @@ class CachingInstanceQueryer:
             if not self.is_asset_in_run(run_id=run_id, asset=asset_key):
                 continue
 
-            for upstream_key, upstream_time in self._get_in_progress_data_times_for_key_in_run(
+            for key, time in self._get_in_progress_data_times_for_key_in_run(
                 run_id=run_id,
                 current_time=current_time,
                 asset_graph=asset_graph,
                 asset_key=asset_key,
-                required_keys=upstream_keys,
             ).items():
-                if upstream_time is not None:
-                    in_progress_times[upstream_key] = max(
-                        in_progress_times.get(upstream_key, upstream_time), upstream_time
-                    )
+                if time is not None:
+                    in_progress_times[key] = max(in_progress_times.get(key, time), time)
         return in_progress_times
 
     def get_failed_data_times_for_key(
@@ -568,9 +540,9 @@ class CachingInstanceQueryer:
         ):
             return {}
 
-        run_failure_time = datetime.datetime.utcfromtimestamp(latest_run_record.end_time).replace(
-            tzinfo=datetime.timezone.utc
-        )
+        run_failure_time = datetime.datetime.utcfromtimestamp(
+            latest_run_record.end_time or latest_run_record.create_timestamp.timestamp()
+        ).replace(tzinfo=datetime.timezone.utc)
         return {
             key: min(run_failure_time, data_time) if data_time is not None else None
             for key, data_time in self._get_in_progress_data_times_for_key_in_run(
@@ -578,7 +550,6 @@ class CachingInstanceQueryer:
                 current_time=run_failure_time,
                 asset_graph=asset_graph,
                 asset_key=asset_key,
-                required_keys=upstream_keys,
             ).items()
         }
 
@@ -604,3 +575,17 @@ class CachingInstanceQueryer:
             evaluation_time=evaluation_time,
             used_data_times=used_data_times,
         )
+
+    def get_latest_storage_id(self, event_type: DagsterEventType) -> Optional[int]:
+        """
+        Returns None if there are no events from that type in the event log.
+        """
+        records = list(
+            self.instance.get_event_records(
+                event_records_filter=EventRecordsFilter(event_type=event_type), limit=1
+            )
+        )
+        if records:
+            return records[0].storage_id
+        else:
+            return None
