@@ -6,7 +6,7 @@ from tempfile import TemporaryDirectory
 import dagster._check as check
 from dagster import file_relative_path
 from dagster._core.test_utils import instance_for_test
-from dagster._utils import merge_dicts
+from dagster._utils.merger import merge_dicts
 
 BUILDKITE = bool(os.getenv("BUILDKITE"))
 
@@ -51,7 +51,7 @@ class TestMySQLInstance:
     @staticmethod
     def dagster_mysql_installed():
         try:
-            import dagster_mysql  # pylint: disable=unused-import
+            import dagster_mysql  # noqa: F401
         except ImportError:
             return False
         return True
